@@ -1,5 +1,11 @@
 #!/usr/bin/env python
+
+# Kemal Inecik
+# k.inecik@gmail.com
+
+
 """Command-line interface."""
+
 import os
 
 import click
@@ -7,13 +13,13 @@ from rich import traceback
 
 
 @click.command()
-@click.version_option(version="0.0.2", message=click.style("idtrack Version: 0.0.2"))
+@click.version_option(version="0.0.3", message=click.style("idtrack Version: 0.0.3"))
 def main() -> None:
     """idtrack."""
     print(
         f"Python Package: `idtrack`{os.linesep}"
         f"Author: `Kemal Inecik <k.inecik@gmail.com>`{os.linesep}"
-        f"Description: `Biological ID matching between different times and/or databases`{os.linesep}"
+        f"Description: `ID mapping between different times, databases, genome assemblies.`{os.linesep}"
         f"Documentation: `https://idtrack.readthedocs.io/en/latest/`"
     )
 
